<?php

namespace Bixo\Aml\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use Bixo\Aml\Http\Requests\NameRequest;
use Bixo\Aml\Interfaces\NameRepositoryInterface;
use Bixo\Aml\Models\Name;
use Bixo\Aml\Forms\Name as Form;

/**
 * APIController  class for name.
 */
class NameAPIController extends BaseController
{

    /**
     * Initialize name resource controller.
     *
     * @param type NameRepositoryInterface $name
     *
     * @return null
     */
    public function __construct(NameRepositoryInterface $name)
    {
        parent::__construct();
        $this->repository = $name;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Bixo\Aml\Repositories\Criteria\NameResourceCriteria::class);
    }

    /**
     * Display a list of name.
     *
     * @return Response
     */
    public function index(NameRequest $request)
    {
        return $this->repository
            ->setPresenter(\Bixo\Aml\Repositories\Presenter\NamePresenter::class)
            ->paginate();
    }

    /**
     * Display name.
     *
     * @param Request $request
     * @param Model   $name
     *
     * @return Response
     */
    public function show(NameRequest $request, Name $name)
    {
        return $name->setPresenter(\Bixo\Aml\Repositories\Presenter\NameListPresenter::class);
        ;
    }

    /**
     * Create new name.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(NameRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('aml::name.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('aml/name/' . $name->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('aml/name');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the name.
     *
     * @param Request $request
     * @param Model   $name
     *
     * @return Response
     */
    public function update(NameRequest $request, Name $name)
    {
        try {
            $data = $request->all();

            $name->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('aml::name.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('aml/name/' . $name->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('aml/name/' . $name->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the name.
     *
     * @param Model   $name
     *
     * @return Response
     */
    public function destroy(NameRequest $request, Name $name)
    {
        try {
            $name->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('aml::name.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('aml/name/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('aml/name/' . $name->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
