<?php

namespace Bixo\Aml\Policies;

use Litepie\User\Contracts\UserPolicy;
use Bixo\Aml\Models\Name;

class NamePolicy
{

    /**
     * Determine if the given user can view the name.
     *
     * @param UserPolicy $user
     * @param Name $name
     *
     * @return bool
     */
    public function view(UserPolicy $user, Name $name)
    {
        if ($user->canDo('aml.name.view') && $user->isAdmin()) {
            return true;
        }

        return $name->user_id == user_id() && $name->user_type == user_type();
    }

    /**
     * Determine if the given user can create a name.
     *
     * @param UserPolicy $user
     * @param Name $name
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('aml.name.create');
    }

    /**
     * Determine if the given user can update the given name.
     *
     * @param UserPolicy $user
     * @param Name $name
     *
     * @return bool
     */
    public function update(UserPolicy $user, Name $name)
    {
        if ($user->canDo('aml.name.edit') && $user->isAdmin()) {
            return true;
        }

        return $name->user_id == user_id() && $name->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given name.
     *
     * @param UserPolicy $user
     * @param Name $name
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Name $name)
    {
        return $name->user_id == user_id() && $name->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given name.
     *
     * @param UserPolicy $user
     * @param Name $name
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Name $name)
    {
        if ($user->canDo('aml.name.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given name.
     *
     * @param UserPolicy $user
     * @param Name $name
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Name $name)
    {
        if ($user->canDo('aml.name.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
