<?php

namespace Bixo\Aml\Policies;

use Litepie\User\Contracts\UserPolicy;
use Bixo\Aml\Models\Nationality;

class NationalityPolicy
{

    /**
     * Determine if the given user can view the nationality.
     *
     * @param UserPolicy $user
     * @param Nationality $nationality
     *
     * @return bool
     */
    public function view(UserPolicy $user, Nationality $nationality)
    {
        if ($user->canDo('aml.nationality.view') && $user->isAdmin()) {
            return true;
        }

        return $nationality->user_id == user_id() && $nationality->user_type == user_type();
    }

    /**
     * Determine if the given user can create a nationality.
     *
     * @param UserPolicy $user
     * @param Nationality $nationality
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('aml.nationality.create');
    }

    /**
     * Determine if the given user can update the given nationality.
     *
     * @param UserPolicy $user
     * @param Nationality $nationality
     *
     * @return bool
     */
    public function update(UserPolicy $user, Nationality $nationality)
    {
        if ($user->canDo('aml.nationality.edit') && $user->isAdmin()) {
            return true;
        }

        return $nationality->user_id == user_id() && $nationality->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given nationality.
     *
     * @param UserPolicy $user
     * @param Nationality $nationality
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Nationality $nationality)
    {
        return $nationality->user_id == user_id() && $nationality->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given nationality.
     *
     * @param UserPolicy $user
     * @param Nationality $nationality
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Nationality $nationality)
    {
        if ($user->canDo('aml.nationality.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given nationality.
     *
     * @param UserPolicy $user
     * @param Nationality $nationality
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Nationality $nationality)
    {
        if ($user->canDo('aml.nationality.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
