<?php

namespace Bixo\Aml\Providers;

use Illuminate\Support\ServiceProvider;

class AmlServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'aml');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'aml');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerAml();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerAml()
    {
        $this->app->bind('aml', function($app) {
            return new Aml($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('Aml', 'Lavalite\Aml\Facades\Aml');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('bixo.aml', function ($app) {
            return $this->app->make('Bixo\Aml\Aml');
        });

        // Bind Name to repository
        $this->app->bind(
            'Bixo\Aml\Interfaces\NameRepositoryInterface',
            \Bixo\Aml\Repositories\Eloquent\NameRepository::class
        );        // Bind Nationality to repository
        $this->app->bind(
            'Bixo\Aml\Interfaces\NationalityRepositoryInterface',
            \Bixo\Aml\Repositories\Eloquent\NationalityRepository::class
        );        // Bind Sanction to repository
        $this->app->bind(
            'Bixo\Aml\Interfaces\SanctionRepositoryInterface',
            \Bixo\Aml\Repositories\Eloquent\SanctionRepository::class
        );

        $this->app->register(\Bixo\Aml\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Bixo\Aml\Providers\RouteServiceProvider::class);
            }

    /**
     * Merges user's and aml's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'bixo.aml'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeAml::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['bixo.aml'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('bixo/aml.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/aml')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/aml')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
