<?php

namespace Bixo\Aml\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Illuminate\Routing\Router;
use Bixo\Aml\Models\Aml;
use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'Bixo\Aml\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/aml/name/*')) {
            Route::bind('name', function ($name) {
                $namerepo = $this->app->make('Bixo\Aml\Interfaces\NameRepositoryInterface');
                return $namerepo->findorNew($name);
            });
        }
        if (Request::is('*/aml/nationality/*')) {
            Route::bind('nationality', function ($nationality) {
                $nationalityrepo = $this->app->make('Bixo\Aml\Interfaces\NationalityRepositoryInterface');
                return $nationalityrepo->findorNew($nationality);
            });
        }
        if (Request::is('*/aml/sanction/*')) {
            Route::bind('sanction', function ($sanction) {
                $sanctionrepo = $this->app->make('Bixo\Aml\Interfaces\SanctionRepositoryInterface');
                return $sanctionrepo->findorNew($sanction);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();

        $this->mapApiRoutes();
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {   
        Route::group([
            'middleware' => 'web',
            'namespace'  => $this->namespace,
        ], function ($router) {
            require (__DIR__ . '/../../routes/web.php');
        });
    }

    /**
     * Define the "api" routes for the package.
     *
     * These routes are typically stateless.
     *
     * @return void
     */
    protected function mapApiRoutes()
    {
        Route::group([
            'middleware' => 'api',
            'namespace'  => $this->namespace,
            'prefix'     => 'api',
        ], function ($router) {
            require (__DIR__ . '/../../routes/api.php');
        });
    }

}
